.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.classify.montgomery_shenzhen_indian_tbx11k_indian_tbx11k_tbx11k:

=======================================================================
 Aggregated databases (Montgomery County, Shenzhen, Indian and TBX11k)
=======================================================================

* DataModule and support code: :py:mod:`.data.classify.montgomery_shenzhen_indian_tbx11k`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``montgomery-shenzhen-indian-tbx11k-v1``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_healthy_vs_atb`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f0``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_0`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f1``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_1`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f2``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_2`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f3``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_3`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f4``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_4`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f5``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_5`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f6``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_6`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f7``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_7`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f8``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_8`
     * - ``montgomery-shenzhen-indian-tbx11k-v1-f9``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v1_fold_9`
     * - ``montgomery-shenzhen-indian-tbx11k-v2``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_others_vs_atb`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f0``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_0`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f1``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_1`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f2``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_2`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f3``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_3`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f4``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_4`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f5``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_5`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f6``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_6`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f7``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_7`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f8``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_8`
     * - ``montgomery-shenzhen-indian-tbx11k-v2-f9``
       - :py:mod:`.config.classify.data.montgomery_shenzhen_indian_tbx11k.v2_fold_9`
